<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Http\Requests;

class Ajax extends Controller
{
    // add to cart 
    public function add_to_cart ( $domain ) {

    	// add this domain to cart
    	try {
            $pricing = (!is_null( $domain->discount ) && ($domain->discount > 0)) ? $domain->discount : $domain->pricing;
    		\Cart::add( $domain->id, $domain->domain, 1, $pricing, 0.00 ); 
    	} catch( \Exception $e ){
    		return $e->getMessage();
    	}

    }

    // cart contents
    public function cart_contents() {

    	$cart = \Cart::content(true);

    	return view('cart')->with( 'cart', $cart );
    }

    // remove from cart
    public function remove_from_cart( $rowId ) {

    	// try removing 
    	try {

    		\Cart::remove( $rowId );

			$r = [ 'message' => 'Product successfully removed from cart.', 
				   'message_type' => 'success' ];

    	} catch ( \Exception $e ) {

			$r = [ 'message' => $e->getMessage(), 
				   'message_type' => 'warning' ];

    	}


    	// return with flash data
    	return redirect('checkout')
    					->with('message', $r['message'])
    					->with('message_type', $r['message_type']);
    	
    }

    // make offer
    public function make_offer( Request $r  ) {
        
        // validation rules
        $rules = [ 'offer-name' => 'required', 'offer-email' => 'required|email', 
                    'offer-price' => 'required', 'offer-answer' => 'required|integer' ];

        // do validation
        $this->validate( $r, $rules );

        // validate security answer
        if( $r->total != $r->{'offer-answer'} ) {
            return response()->json(['message' => '<div class="alert alert-danger">Hmmmm.. is your math so bad today?</div>']);
        }

        // domain info
        $domain = \App\Domain::find( $r->domainId );
        if( !$domain )    
            return response()->json([ 'message' => '<div class="alert alert-danger">Invalid Domain Id!</div>']);

        // set mail variables
        $offer = $r->all();


        // mail the admin
        \Mail::send('emails.admin-new-offer', [ 'offer' => $offer, 'domain' => $domain ], function ($m) use( $offer, $domain ) {
            $m->from(env('SENDING_EMAIL'), \App\Options::get_option('site_title'));
            $m->replyTo($offer['offer-email'], $offer[ 'offer-name' ]);
            $m->to(\App\Options::get_option('admin_email'), 'Admin')->subject('You\'ve got an Offer!');
        });

        // message
        $message = '<script>$(function() { $( ".make-offer-form-div" ).hide( "slow" ) });</script>';
        $message .= '<div class="alert alert-warning">You offer has been received! <br />We will get back to you soon.</div> Click outside of this window to close!';

        return response()->json([ 'message' => $message ]);

    }

    // make financing
    public function make_financing( Request $r  ) {
        
        // validation rules
        $rules = [ 'financing-name' => 'required', 'financing-email' => 'required|email', 
                    'financing-months' => 'required', 'financing-answer' => 'required|integer' ];

        // do validation
        $this->validate( $r, $rules );

        // validate security answer
        if( $r->total != $r->{'financing-answer'} ) {
            return response()->json(['message' => '<div class="alert alert-danger">Hmmmm.. is your math so bad today?</div>']);
        }

        // domain info
        $domain = \App\Domain::find( $r->domainId );
        if( !$domain )    
            return response()->json([ 'message' => '<div class="alert alert-danger">Invalid Domain Id!</div>']);

        // set mail variables
        $financing = $r->all();


        // mail the admin
        \Mail::send('emails.admin-new-financing', [ 'offer' => $financing, 'domain' => $domain ], function ($m) use( $financing, $domain ) {
            $m->from(env('SENDING_EMAIL'), \App\Options::get_option('site_title'));
            $m->replyTo($financing['financing-email'], $financing[ 'financing-name' ]);
            $m->to(\App\Options::get_option('admin_email'), 'Admin')->subject('You\'ve got a financing request!');
        });

        // message
        $message = '<script>$(function() { $( ".make-financing-div" ).hide( "slow" ) });</script>';
        $message .= '<div class="alert alert-warning">You financing request has been received! <br />We will get back to you soon.</div> Click outside of this window to close!';

        return response()->json([ 'message' => $message ]);

    }

    // ajax domain filtering
    public function domain_filtering( Request $r ) {

        // filter sorting option
        $allowedSort = [ 'id.desc', 'pricing.asc', 'pricing.desc', 'domain.asc' ];

        if( !in_array( $r->sortby, $allowedSort ) )
            die( 'Invalid sort order' );

        // validate others
        $this->validate( $r, [ 'category' => 'required|integer', 
                                'age' => 'required|integer', 
                                'length' => 'required|integer', 
                                'pricing' => 'required|integer'] );

        $orderBy = explode( '.', $r->sortby );
        
        // get domains list ( apply order filter )
        if( 'pricing.desc' == $r->sortby || 'pricing.asc' == $r->sortby ) {
            $domains = \App\Domain::orderByRaw('(CASE WHEN (discount != 0 AND discount IS NOT NULL)
                                                 THEN 
                                                    discount 
                                                ELSE 
                                                    pricing 
                                                END) ' . $orderBy[ 1 ]);
        }else{
            $domains = \App\Domain::orderBy( $orderBy[ 0 ], $orderBy[ 1 ] );
        }


        // apply category filter ( if required )
        if( $r->category > 0 )
            $domains->where( 'category', $r->category );

        // apply TLD filter ( if required )
        if( $r->extension != '' )
            $domains->where( 'domain', 'like', '%' . $r->extension );

        // apply keyword filter ( if required )
        if( $r->keyword != '' )
            $domains->where( 'domain', 'like', '%' . $r->keyword . '%' );

        // apply price filter ( if required )
        if( $r->pricing > 0 )
            $domains->where( 'pricing', '>=', $r->pricing );

        // apply NOT SOLD domains
        $domains->where('domain_status', '!=', 'SOLD');

        $d = $domains->get();

        // apply age filter ( if required )
        if( $r->age > 0 ) {
            $d = $d->reject(function ($domain) use ( $r ) {
                return \App\Domain::computeAge($domain->reg_date, '') <= $r->age;
            });
        }

        // apply length filter ( if required )
        if( $r->length > 0 ) {
            $d = $d->filter(function ($domain) use ( $r ) {
                return \App\Domain::getCharacterCount($domain->domain) >= $r->length;
            });
        }

        if( !count( $d ) )
            return '<h3 class="text-center"><i class="fa fa-alert"></i> No domains matching the selected criteria</h3><br/><br/>';


        return view('all-domains-ajax-filtered')->with( 'domains', $d );

    }

}
