<?php

namespace App;

use Illuminate\Database\Eloquent\Model;

class Domain extends Model
{
    // no timestamps
    public $timestamps = false;

    // fillable
    protected $fillable = [
        'domain', 'pricing', 'registrar', 'reg_date', 'exp_date',
        'domain_age', 'description', 'short_description', 'discount',
        'category', 'financing_price'
    ];

    // get available extensions
    public static function getAvailableExtensions()
    {

        // get all domains from DB
        $all_domains = self::select('domain')->get();

        // setup extensions array
        $extensions = [];

        $regex = '/(?:www\.)?[a-zA-Z\-0-9]+\.([\.a-zA-Z]+)/i';

        // loop
        foreach ($all_domains as $domain) {

            $extension = preg_match($regex, $domain, $tlds);
            array_push($extensions, end($tlds));
        }

        return array_unique($extensions, SORT_STRING);
    }

    // get character count
    public static function getCharacterCount($domainName)
    {

        return strlen(strtok($domainName, '.'));
    }


    // compute age
    public static function computeAge($reg_date, $exp_date)
    {

        // parse dates
        $reg_date = \Carbon\Carbon::parse($reg_date);
        $exp_date = \Carbon\Carbon::parse(date('Y-m-d'));

        // years difference
        $years_diff = $exp_date->diffInYears($reg_date);

        // return age difference
        return $years_diff;
    }


    // use "domain" for the model injection into routes
    public function getRouteKeyName()
    {
        return 'domain';
    }

    // has one category
    public function industry()
    {
        return $this->hasOne('App\Categories', 'catID', 'category');
    }
}
