<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Http\Controllers\Controller;
use App\Page;
use App\Navi;
use App\Options;
use App\Domain;
use App\Orders;
use App\Categories;
use Mail;

class Admin extends Controller
{

    // GET|POST /admin/login
    public function login()
    {

        $message = '';

        if (\Request::isMethod('post')) {
            if (\Input::has('ausername') and \Input::has('apassword')) {
                if (
                    \Input::get('ausername') == env('ADMIN_USER') and
                    \Input::get('apassword') == env('ADMIN_PASS')
                ) {
                    \Session::put('admin', 'true');
                    return redirect('admin');
                } else {
                    $message = '<div class="alert alert-danger">Invalid login.</div>';
                }
            } else {
                $message = '<div class="alert alert-danger">User/password required</div>';
            }
        }

        return view('admin-login')->with('message', $message);
    }

    // GET /admin/logout
    public function logout()
    {
        \Session::forget('admin');
        return redirect('/admin/login');
    }

    public function dashboard()
    {

        // if remove
        if ($removeId = \Input::get('remove')) {

            // remove from db
            $d = Orders::findOrFail($removeId);
            $d->delete();

            return redirect('admin')->with('msg', 'Successfully removed order "#' . $d->id . '"');
        }

        // orders ( list all )
        $orders = Orders::orderBy('id', 'DESC')->get();

        // earnings & sales MTD
        $mtd_count = Orders::where('order_date', '>=', \Carbon\Carbon::now()->startOfMonth())
            ->where('order_status', '=', 'Paid')
            ->count();
        $earnings_mtd = Orders::where('order_date', '>=', \Carbon\Carbon::now()->startOfMonth())
            ->where('order_status', '=', 'Paid')
            ->sum('total');


        // earnings & sales ALL TIME
        $all_time_earnings = Orders::where('order_status', '=', 'Paid')->sum('total');
        $all_time_sales = Orders::where('order_status', '=', 'Paid')->count();

        // earnings past 30 days
        $date = \Carbon\Carbon::parse('31 days ago');

        $days = Orders::select(array(
            \DB::raw('DATE(`order_date`) as `date`'),
            \DB::raw('SUM(`total`) as `total`')
        ))
            ->where('order_date', '>', $date)
            ->groupBy('date')
            ->orderBy('date', 'DESC')
            ->lists('total', 'date');

        // finally, return the view
        return view('admin.dashboard')
            ->with('active', 'dashboard')
            ->with('orders', $orders)
            ->with('mtd_count', $mtd_count)
            ->with('earnings_mtd', $earnings_mtd)
            ->with('all_time_sales', $all_time_sales)
            ->with('all_time_earnings', $all_time_earnings)
            ->with('earnings_30_days', $days);
    }

    // view order info
    public function view_order(\App\Orders $order)
    {

        // order contents unserialize
        $order_content = json_decode($order->order_contents);

        // return view 
        return view('admin.view-order')
            ->with('active', 'dashboard')
            ->with('order', $order)
            ->with('order_content', $order_content);
    }

    // dashboard stats
    public function domains_overview()
    {

        // if remove
        if ($removeId = \Input::get('remove')) {

            // remove from db
            $d = Domain::findOrFail($removeId);
            $d->delete();

            return redirect('admin/domains')->with('msg', 'Successfully removed domain "' . $d->domain . '"');
        }


        $domains = Domain::orderBy('id', 'DESC')->get();

        // append domain age to the list
        $domains->map(function ($d) {
            $d->domain_age = Domain::computeAge($d->reg_date, 0);
        });

        return view('admin.domains-overview')
            ->with('active', 'domains')
            ->with('domains', $domains);
    }

    // categories
    public function categories_overview()
    {

        // if remove
        if ($removeId = \Input::get('remove')) {

            // remove from db
            $d = Categories::findOrFail($removeId);
            $d->delete();

            return redirect('admin/categories')->with('msg', 'Successfully removed category "' . $d->catname . '"');
        }


        // if update
        $catname = '';
        $catID = '';
        if ($updateCat = \Input::get('update')) {

            // find category
            $c = Categories::findOrFail($updateCat);
            $catname = $c->catname;
            $catID = $c->catID;
        }

        $categories = Categories::orderBy('catname', 'ASC')->get();

        return view('admin.categories')
            ->with('active', 'categories')
            ->with('categories', $categories)
            ->with('catname', $catname)
            ->with('catID', $catID);
    }

    // add category
    public function add_category(Request $r)
    {

        $this->validate($r, ['catname' => 'required']);

        $c = new Categories;
        $c->catname = $r->catname;
        $c->save();

        return redirect('admin/categories')->with('msg', 'Category successfully created.');
    }

    // update category
    public function update_category(Request $r)
    {

        $this->validate($r, ['catname' => 'required']);

        $c = Categories::findOrFail($r->catID);
        $c->catname = $r->catname;
        $c->save();

        return redirect('admin/categories')->with('msg', 'Category successfully updated.');
    }

    // add domain name listing
    public function add_domain()
    {

        $categories = \App\Categories::all()->toArray();
        return view('admin.add-domain')->with('categories', $categories);
    }

    // bulk upload
    public function bulk_upload()
    {
        return view('admin.bulk-upload')->with('active', 'bulk');
    }

    // bulk upload processing
    public function bulk_upload_process(Request $r)
    {

        // validate file
        $this->validate($r, ['csv' => 'required|file']);

        // process the csv
        $csv_file = $r->file('csv')->getPathname();
        $handle   = fopen($csv_file, 'r');

        $row = 1;

        // insert array
        $insert = [];

        while (($data = fgetcsv($handle, 0, ",")) !== FALSE) {

            // get lines count
            $num = count($data);

            // increase rows
            $row++;

            // setup fields
            $i['domain'] = $data[0];
            $i['pricing'] = intval($data[1]);
            $i['registrar'] = $data[2];
            $i['reg_date'] = $data[3];
            $i['short_description'] = $data[4];
            $i['description'] = $data[5];
            $i['domain_status'] = 'Available';
            $i['domain_logo'] = 'default-logo.jpg';

            // grab image if we have it
            if (isset($data[6])) {

                // set filename
                $filename = str_slug($i['domain']);

                // move file
                $path = base_path() . '/domain-logos/' . $filename;
                $thumbnail_path = base_path() . '/domain-logos/thumbnail-' . $filename;

                // get extension
                $extension = pathinfo($data[6], PATHINFO_EXTENSION);

                // save to path
                $saveto = $path . '.' . $extension;

                $ch = curl_init($data[6]);
                curl_setopt($ch, CURLOPT_HEADER, 0);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
                curl_setopt($ch, CURLOPT_BINARYTRANSFER, 1);
                $raw = curl_exec($ch);
                curl_close($ch);
                if (file_exists($saveto)) {
                    unlink($saveto);
                }
                $fp = fopen($saveto, 'x');
                fwrite($fp, $raw);
                fclose($fp);

                // create thumbnail & save
                $img = \Image::make($saveto);
                $img->resize(null, 98, function ($constraint) {
                    $constraint->aspectRatio();
                    $constraint->upsize();
                });

                $img->save($thumbnail_path . '.' . $extension);

                $i['domain_logo'] = basename($saveto);
            } // if we have image file

            $insert[] = $i;
        } // the csv lines loop

        // close handle to the temp file
        fclose($handle);

        // create domains
        if (count($insert))
            Domain::insert($insert);

        return redirect('admin/bulk-domains')->with('msg', 'Found <strong>' . $row . '</strong> total domains');
    }

    // add domain to database
    public function add_domain_process(Request $r)
    {

        // validate min fields
        $this->validate($r, [
            'domain' => 'required',
            'pricing' => 'required|numeric|min:1',
            'reg_date' => 'required|date_format:d-m-Y',
            'domain_logo' => 'image',
        ]);

        // save this domain
        $d = Domain::create($r->except(['sb', '_token', '_wysihtml5_mode']));


        if (empty($r->financing_price)) {
            $d->financing_price = null;
            $d->save();
        }

        // add domain logo ( if any )
        if ($r->hasFile('domain_logo')) {

            // set file info
            $file = $r->file('domain_logo');
            $filename = str_slug($r->domain) . '.' . $file->getClientOriginalExtension();

            // move file
            $file->move(base_path() . '/domain-logos/', $filename);

            // create thumbnail & save
            $img = \Image::make(base_path() . '/domain-logos/' . $filename);
            $img->resize(null, 98, function ($constraint) {
                $constraint->aspectRatio();
                $constraint->upsize();
            });

            $img->save(base_path() . '/domain-logos/thumbnail-' . $filename);

            // set logo in db
            $d->domain_logo = $filename;
            $d->save();
        } else {
            $d->domain_logo = 'default-logo.jpg';
            $d->save();
        }

        // redirect with message
        return redirect('/admin/manage-domain/' . $d->domain)->with('msg', 'Domain successfully created.');
    }

    // manage domain name listing
    public function manage_domain(\App\Domain $domain)
    {

        $categories = \App\Categories::all()->toArray();
        return view('admin.manage-domain')->with('d', $domain)->with('categories', $categories);
    }

    // update domain details
    public function manage_domain_update(\App\Domain $domain, Request $r)
    {

        // validate min fields
        $this->validate($r, ['domain' => 'required', 'pricing' => 'required']);

        // update domain age
        $domain->domain_status = $r->domain_status;
        $domain->save();

        // updated domain logo ( if any )
        if ($r->hasFile('domain_logo')) {

            // set file info
            $file = $r->file('domain_logo');
            $filename = str_slug($r->domain) . '.' . $file->getClientOriginalExtension();

            // move file
            $file->move(base_path() . '/domain-logos/', $filename);

            // create thumbnail & save
            $img = \Image::make(base_path() . '/domain-logos/' . $filename);
            $img->resize(null, 98, function ($constraint) {
                $constraint->aspectRatio();
                $constraint->upsize();
            });

            $img->save(base_path() . '/domain-logos/thumbnail-' . $filename);

            // set logo in db
            $domain->domain_logo = $filename;
            $domain->save();
        }

        // update db
        $domain->update($r->except(['sb', '_token', '_wysihtml5_mode']));

        if (empty($r->financing_price)) {
            $domain->financing_price = null;
            $domain->save();
        }

        // redirect with message 
        return redirect('admin/manage-domain/' . $domain->domain)
            ->with('msg', 'Domain details successfully saved.');
    }

    // pages controller
    public function pages()
    {

        // get existent pages
        $pages = Page::all();

        return view('admin.pages')->with('pages', $pages)
            ->with('active', 'pages');
    }

    // create a page
    public function create_page(Request $r)
    {

        // validate form entries
        $this->validate($r, ['page_title' => 'unique:pages|required']);

        // save page
        $page = new Page;
        $page->page_title = $r->page_title;
        $page->page_slug  = str_slug($r->page_title);
        $page->page_content = $r->page_content;
        $page->save();

        return redirect()->route('admin-cms')->with('msg', 'Page successfully created');
    }

    // navigation controller
    public function navigation()
    {

        // get existent menu items
        $navi_order = Options::get_option('navi_order');

        if ($navi_order && !empty($navi_order)) {
            $navi = Navi::orderByRaw("FIELD(id, $navi_order)")->get();
        } else {
            $navi = Navi::all();
        }

        return view('admin.navigation')->with('navi', $navi)
            ->with('active', 'navi');
    }

    // create navigation item
    public function navigation_save(Request $r)
    {

        // save and redirect
        Navi::create($r->except('sb_navi', '_token'));

        return redirect('admin/navigation')->with('msg', 'Item successfully added to navigation');
    }


    // appearance setup
    public function appearance()
    {
        return view('admin.appearance')->with('active', 'appearance');
    }
}
