<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Http\Requests;
use App\Domain;
use App\Categories;
use App\Options;

class Main extends Controller
{
    // home controller
    public function home()
    {

        // parking feature: redirect to individual domain page
        $hostname = str_replace("www.", "", strtolower($_SERVER['SERVER_NAME']));
        $domain = Domain::where(\DB::raw('LOWER(domain)'), $hostname)->first();


        // if we found -> redirect
        if ($domain)
            return redirect(env('FULL_SITE_URL') . '/' . $domain->domain);

        // get domain list from database
        $domain_list = Domain::orderBy('id', 'DESC')
            ->where('domain_status', '!=', 'SOLD')
            ->take(6)
            ->get();

        // append domain age to the list
        $domain_list->map(function ($d) {
            $d->domain_age = Domain::computeAge($d->reg_date, 0);
        });

        // return homepage
        return view('homepage')->with('domains', $domain_list)->with('isHome', true);
    }

    // domain info controller
    public function domain_info($domain)
    {

        $no1   = rand(1, 5);
        $no2   = rand(1, 5);
        $total = $no1 + $no2;

        $domain->domain_age = Domain::computeAge($domain->reg_date, 0);

        return view('domain-info')
            ->with('domain', $domain)
            ->with('no1', $no1)
            ->with('no2', $no2)
            ->with('total', $total);
    }


    // all domains
    public function all_domains()
    {


        // $faker = \Faker\Factory::create();

        // for( $i = 0; $i <= 50; $i++ ) {

        //     $reg_date = $faker->date('d-m-Y');
        //     $exp_date = $faker->date('d-m-Y');

        //     $insert = ['domain' => $faker->domainName, 
        //                 'pricing' => $faker->numberBetween(100, 100000), 
        //                 'registrar' => $faker->firstName, 
        //                 'reg_date' => date("d-m-Y", strtotime("-" . rand(1,5) . " Years")), 
        //                 'short_description' => $faker->sentence(10), 
        //                 'description' => $faker->paragraphs(4,1), 
        //                 'category' => 1, 
        //                 'discount' =>  $faker->numberBetween(0, 100000)];

        //     $new_domain = \App\Domain::create( $insert );
        // }

        // exit;


        // get domain list from database
        $domain_list = Domain::orderBy('id', 'DESC')
            ->where('domain_status', '!=', 'SOLD')
            ->get();


        // append domain age to the list
        $domain_list->map(function ($d) {
            $d->domain_age = Domain::computeAge($d->reg_date, 0);
        });


        // get tlds
        $tlds  = Domain::getAvailableExtensions();

        // get categories
        $categories = Categories::orderBy('catname', 'ASC')->get();

        // if keyword is set autofill keyword
        $autoKeyword = '';
        $autoSearch = '';

        if (\Input::has('keyword')) {
            $autoKeyword = trim(strip_tags(\Input::get('keyword')));
            $autoSearch = "<script>$(function() { $( '#ajax-search-form' ).trigger('submit'); });</script>";
        }


        // show view
        return view('all-domains')
            ->with('domains', $domain_list)
            ->with('tlds', $tlds)
            ->with('categories', $categories)
            ->with('autoSearch', $autoSearch)
            ->with('autoKeyword', $autoKeyword);
    }

    // Contact page route
    public function contact()
    {

        $no1   = rand(1, 5);
        $no2   = rand(1, 5);
        $total = $no1 + $no2;

        return view('contact')
            ->with('no1', $no1)
            ->with('no2', $no2)
            ->with('total', $total);;
    }

    // Process contact form entry
    public function process_contact(Request $r)
    {

        // validate contact form
        $validator = \Validator::make($r->all(), [
            'name' => 'required',
            'subject' => 'required',
            'email' => 'required|email',
            'message' => 'required|min:10',
            'offer-answer' => 'required|integer',
        ]);

        if ($validator->fails()) {
            return redirect('contact')
                ->withErrors($validator)
                ->withInput();
        }


        // send email to admin
        $from = \Input::get('email');

        try {

            \Mail::send('emails.contact-notification', ['input' => \Input::all()], function ($m) use ($from) {

                $m->to(\App\Options::get_option('admin_email'), 'Site Admin')
                    ->subject('New Contact Form Message')
                    ->from($from);
            });

            return redirect('contact')
                ->with('message', 'Thank you for contacting us, we will get back to you soon!');
        } catch (\Exception $e) {

            return redirect('contact')
                ->with('message', $e->getMessage());
        }
    }

    // upgrade from v1.3 to v1.4
    public function upgrade()
    {
        return view('upgrade');
    }

    // upgrade processing
    public function upgrade_process(Request $r)
    {

        $license = Options::get_option('license_key');
        $result = $this->check_license($license, env('FULL_SITE_URL'));

        //if LICENSE_VALID_AUTOUPDATE_ENABLED
        if ($result == 'LICENSE_VALID_AUTOUPDATE_ENABLED') {
            // adjust domains table
            try {
                \DB::statement("ALTER TABLE `domains` ADD `financing_price` INT NULL DEFAULT NULL AFTER `pricing`;");
                return redirect('upgrade-foliotrader')->with('message', 'DB Upgrade Successfully Complete. If you haven\'t yet, don\'t forget to also upload the files from upgrade/ folder!');
            } catch (\Exception $e) {
                return redirect('upgrade-foliotrader')->with('message', $e->getMessage());
            }
        } else {
            return redirect('upgrade-foliotrader')->with('message', $result);
        }
    }

    public function activate_product(Request $r)
    {

        $this->validate($r, ['license' => 'required', 'domain' => 'required']);

        $result = $this->check_license($r->license, $r->domain);

        //if LICENSE_VALID_AUTOUPDATE_ENABLED
        if ($result == 'LICENSE_VALID_AUTOUPDATE_ENABLED') {

            \App\Options::update_option('license_key', $r->license);

            return redirect('validate-license')->with('message', 'Successfully validated. You can now continue using the product!');
        } else {
            return redirect('validate-license')->with('message', $result);
        }
    }

    protected function check_license($license, $domain)
    {

        // call url for licensing
        $url = 'http://crivion.com/envato-licensing/index.php';

        //open connection
        $ch = curl_init();

        //set the url, number of POST vars, POST data
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_POST, 2);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, 'license_code=' . $license . '&blogURL=' . $domain);
        curl_setopt($ch, CURLOPT_USERAGENT, 'crivion/envato-license-checker-v1.0');

        //execute post
        $result = curl_exec($ch);

        //close connection
        curl_close($ch);

        return $result;
    }
}
